Observations (``taurex.spectrum``)
==================================


Base
------------------------------------

.. automodule:: taurex.data.spectrum.spectrum
   :members:
   :undoc-members:
   :show-inheritance:

Array
------------------------------------

.. automodule:: taurex.data.spectrum.array
   :members:
   :undoc-members:
   :show-inheritance:

Observed
------------------------------------

.. automodule:: taurex.data.spectrum.observed
   :members:
   :undoc-members:
   :show-inheritance:

Iraclis
------------------------------------

.. automodule:: taurex.data.spectrum.iraclis
   :members:
   :undoc-members:
   :show-inheritance:

Taurex
------------------------------------

.. automodule:: taurex.data.spectrum.taurex
   :members:
   :undoc-members:
   :show-inheritance:


Lightcurves
--------------------------------------

.. automodule:: taurex.data.spectrum.lightcurve
   :members:
   :undoc-members:
   :show-inheritance:
